@@ -1,6 +1,6 @@
 ;;; ebdb-gnus.el --- Gnus interface to EBDB          -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2020  Free Software Foundation, Inc.
+;; Copyright (C) 2016-2023  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 
@@ -213,15 +213,16 @@ based on the contents of the EBDB.
 Mail address elements are already `regexp-quote'-ed, so we just
 concat them.  Please note: in order that this will work with the
 `nnimap-split-fancy' or `nnmail-split-fancy' methods you have to
-use a backquote template, that is your setting will look like:
+use a backquote template, in other words your Gnus server
+variable will look like:
 
-\(setq nnimap-split-rule  'nnimap-split-fancy
-       nnimap-split-inbox \"INBOX\"
-       nnimap-split-fancy
-       `(| ,@(ebdb/gnus-split-folders-list)
-            ... ))
+\(nnimap \"imap.example.com\"
+        (nnimap-inbox \"INBOX\")
+        (nnimap-split-fancy
+        \\=`(| ,@(ebdb/gnus-split-folders-list)
+            ... )))
 
-Note that `( is the backquote, NOT the quote '(."
+Note that \\=`( is the backquote, NOT the quote \\='(."
   (mapcar
    (lambda (elt)
      (list "From"
@@ -336,8 +337,11 @@ composed to a certain record."
 	    (apply #'message-mail (ebdb-dwim-mail record mail) args)))
       (cl-call-next-method))))
 
+;;;###autoload
 (defun ebdb-insinuate-gnus ()
   "Hook EBDB into Gnus."
+  (unless ebdb-db-list
+    (ebdb-load))
   ;; `ebdb-mua-display-sender' fails in *Article* buffers, where
   ;; `gnus-article-read-summary-keys' provides an additional wrapper
   ;; that restores the window configuration.
