@@ -1,6 +1,6 @@
 ;;; ebdb-i18n-basic.el --- Basic internationalization methods for EBDB  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2017  Free Software Foundation, Inc.
+;; Copyright (C) 2017-2023  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 
@@ -29,6 +29,11 @@
   ;; For `with-slots'.
   (require 'eieio))
 
+(declare-function ebdb-i18n-countries "ebdb-i18n")
+(declare-function ebdb-with-exit "ebdb")
+(declare-function ebdb-address-region "ebdb")
+(declare-function ebdb-read-string "ebdb")
+
 ;;; USA
 
 (defvar ebdb-i18n-usa-states
@@ -118,6 +123,9 @@ number, and any remaining as an extension."
       (args-out-of-range nil))
     slots))
 
+;; Defined in `ebdb.el'
+(defvar ebdb-default-phone-country)
+
 (cl-defmethod ebdb-string-i18n ((phone ebdb-field-phone)
 				(_cc (eql 1)))
   (with-slots (area-code number extension) phone
@@ -232,12 +240,11 @@ itself."
 			 (setq str (replace-regexp-in-string
 				    extension-regexp "" str))))))
 
-    (condition-case nil
-	(setq slots (plist-put
-		     slots
-		     :number
-		     (replace-regexp-in-string
-		      "[^[:digit:]]" "" str))))
+    (setq slots (plist-put
+		 slots
+		 :number
+		 (replace-regexp-in-string
+		  "[^[:digit:]]" "" str)))
     slots))
 
 (defvar ebdb-i18n-german-states
