@@ -1,6 +1,6 @@
 ;;; ebdb-mhe.el --- EBDB interface to mh-e           -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2021  Free Software Foundation, Inc.
+;; Copyright (C) 2016-2023  Free Software Foundation, Inc.
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 (require 'mh-e)
 (if (fboundp 'mh-version)
     (require 'mh-comp))              ; For mh-e 4.x
-(require 'advice)
 
 (defgroup ebdb-mua-mhe nil
   "EBDB customizations for mhe."
@@ -137,19 +136,23 @@ Returns the empty string if HEADER is not in the message."
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+;;;###autoload
 (defun ebdb-insinuate-mh ()
   "Hook EBDB into MH-E."
+  (unless ebdb-db-list
+    (ebdb-load))
   (define-key mh-folder-mode-map ";" ebdb-mua-keymap)
   (when ebdb-complete-mail
-      (define-key mh-letter-mode-map "\M-;" 'ebdb-complete-mail)
-      (define-key mh-letter-mode-map "\e\t" 'ebdb-complete-mail)))
+    (define-key mh-letter-mode-map "\M-;" #'ebdb-complete-mail)
+    (define-key mh-letter-mode-map "\e\t" #'ebdb-complete-mail)))
 
+;;;###autoload
 (defun ebdb-mhe-auto-update ()
   (ebdb-mua-auto-update ebdb-mhe-auto-update-p))
 
-(add-hook 'mh-show-hook 'ebdb-mhe-auto-update)
+(add-hook 'mh-show-hook #'ebdb-mhe-auto-update)
 
-(add-hook 'mh-folder-mode-hook 'ebdb-insinuate-mh)
+(add-hook 'mh-folder-mode-hook #'ebdb-insinuate-mh)
 
 (provide 'ebdb-mhe)
 ;;; ebdb-mhe.el ends here
